@@ -111,7 +111,7 @@ class Proxy(DjangoHandlerMixin, RequestHandler):
             image = Image.objects.filter(id=id).first()
             images.append(image)
 
-        document = helpers.create_revision(
+        document = helpers.create_doc(
             journal.editor,
             template,
             title,
@@ -177,10 +177,11 @@ class Proxy(DjangoHandlerMixin, RequestHandler):
         body_json = json_decode(response.body)
         self.submission.ojs_jid = body_json["submission_id"]
         self.submission.save()
+
         # We save the author ID on the OJS site. Currently we are NOT using
         # this information for login purposes.
         author = Author.objects.filter(
-            submission=self.submission, ojs_jid=body_json["user_id"]
+            submission=self.submission.id, ojs_jid=body_json["user_id"]
         ).first()
         if author is None:
             Author.objects.create(
@@ -191,6 +192,7 @@ class Proxy(DjangoHandlerMixin, RequestHandler):
             AccessRight.objects.create(
                 document=self.revision.document,
                 holder_obj=self.user,
+                path=self.revision.document.path,
                 rights="read-without-comments",
             )
 
